@@ -6,20 +6,33 @@ OC.L10N.register(
     "Download" : "Last ned",
     "Groups" : "Grupper",
     "Group name" : "Gruppenamn",
+    "Circles" : "Sirklar",
     "Rename" : "Gje nytt namn",
+    "Enabled" : "Aktivert",
     "Delete" : "Ta bort",
     "can edit" : "kan endra",
     "First name" : "Fornamn",
     "Last name" : "Etternamn",
     "Last modified" : "Siste endra",
+    "Password protection" : "Password protection",
+    "Save" : "Lagre",
+    "Description" : "Skildring",
     "Invalid image" : "Ugyldig bilete",
     "Name" : "Namn",
     "Title" : "Tittel",
     "Cancel" : "Avbryt",
+    "Pending" : "Under vegs",
     "Close" : "Lukk",
     "Import" : "Importer",
     "Not grouped" : "Ikkje gruppert",
+    "Circle" : "Sirkel",
+    "User" : "Bruker",
+    "Group" : "Gruppe",
     "Email" : "E-post",
+    "Moderator" : "Moderator",
+    "Admin" : "Administrer",
+    "Owner" : "Owner",
+    "Users" : "Brukarare",
     "Nickname" : "Kallenamn",
     "Additional names" : "Andre namn",
     "Notes" : "Notat",
