@@ -6,23 +6,42 @@ OC.L10N.register(
     "Contacts" : "Contactes",
     "Loading …" : "Cargament…",
     "Download" : "Telecargar",
+    "Send email" : "Enviar email",
     "Groups" : "Gropes",
     "Group name" : "Nom del grop",
+    "Circles" : "Cercles",
     "Rename" : "Renomenar",
+    "Enabled" : "Activada",
     "Delete" : "Suprimir",
     "Copy link" : "Copiar lo ligam",
     "can edit" : "pòt modificar",
     "First name" : "Prenom",
     "Last name" : "Nom",
     "Display name" : "Nom afichat",
+    "Password protection" : "Proteccion per senhal",
+    "Save" : "Enregistrar",
+    "Description" : "Descripcion",
+    "Invalid image" : "Imatge invalid",
     "Name" : "Nom",
+    "Company" : "Entrepresa",
     "Title" : "Títol",
     "Cancel" : "Anullar",
     "New contact" : "Contacte novèl",
+    "Search contacts …" : "Cercar pels contactes…",
+    "No results" : "Cap de resultat",
+    "Pending" : "En espèra",
     "Close" : "Tampar",
     "Import" : "Importar",
     "Not grouped" : "Pas gropats",
+    "Recently contacted" : "Contactat recentament",
+    "User" : "User",
+    "Group" : "Grop",
     "Email" : "Adreça corrièl",
+    "Contact" : "Contacte",
+    "Admin" : "Admin",
+    "Owner" : "Owner",
+    "Visibility" : "Visibilitat",
+    "Users" : "Utilizaires",
     "Nickname" : "Escais",
     "Additional names" : "Noms suplementaris",
     "Notes" : "Nòtas",
@@ -38,6 +57,7 @@ OC.L10N.register(
     "Postal code" : "Còde postal",
     "Country" : "País",
     "Birthday" : "Anniversari",
+    "Anniversary" : "Anniversari",
     "Instant messaging" : "Messatjariá instantanèa",
     "Phone" : "Telefòn",
     "Mobile" : "Mobil",
