@@ -31,6 +31,7 @@ OC.L10N.register(
     "Group name" : "群組名稱",
     "Circles" : "小圈圈",
     "Create a new circle" : "建立新的小圈圈",
+    "Contacts settings" : "聯絡人設定",
     "Show all groups" : "顯示所有群組",
     "Collapse groups" : "折疊群組",
     "Show all circles" : "顯示所有小圈圈",
@@ -73,10 +74,12 @@ OC.L10N.register(
     "Update avatars from social media" : "從社群媒體更新大頭照",
     "(refreshed once per week)" : "（每週重新整理一次）",
     "Address books" : "通訊錄",
+    "Manages" : "管理",
+    "Oversees" : "監督",
     "An error happened during the config change" : "變更設定時發生錯誤",
     "Password protection" : "密碼保護",
     "Enforce password protection on files shared to this circle" : "對分享到此小圈圈的檔案加上密碼保護",
-    "Use a unique password for all shares to this circles" : "對此小圈圈的所有分享使用獨一無二的密碼",
+    "Use a unique password for all shares to this circle" : "對此小圈圈的所有分享使用獨一無二的密碼",
     "Unique password …" : "獨一無二的密碼……",
     "Save" : "儲存",
     "Change unique password" : "變更獨一無二的密碼",
@@ -121,7 +124,7 @@ OC.L10N.register(
     "Address book" : "通訊錄",
     "New contact" : "新聯絡人",
     "Syntax error. Cannot open the contact." : "語法錯誤。無法開啟聯絡人。",
-    "The contact doesn't exists anymore on the server." : "聯絡人不再存在於伺服器上。",
+    "The contact does not exists on the server anymore." : "伺服器上不再存在該聯絡人。",
     "Unable to retrieve the contact from the server, please check your network connection." : "無法從伺服器擷取聯絡人，請檢查您的網路連線。",
     "An error occurred while trying to move the contact" : "嘗試移動聯絡人時發生錯誤",
     "An error occurred while trying to copy the contact" : "嘗試複製聯絡人時發生錯誤",
@@ -160,6 +163,8 @@ OC.L10N.register(
     "Could not delete the member {displayName}" : "無法刪除成員 {displayName}",
     "Could not change the member level to {level}" : "無法變更成員等級至 {level}",
     "Could not accept membership request" : "無法接受成員請求",
+    "Chart" : "圖表",
+    "Select chart …" : "選取圖表……",
     "Select type" : "選取類型",
     "Select Date" : "選取日期",
     "Add contact in group" : "新增聯絡人到群組",
@@ -187,6 +192,7 @@ OC.L10N.register(
     "Could not copy link to the clipboard." : "無法複製連結至剪貼簿。",
     "Not grouped" : "未歸類",
     "Recently contacted" : "最近聯絡",
+    "Organization chart" : "組織圖表",
     "Circles allow you to create groups with other users on a Nextcloud instance and share with them." : "小圈圈讓您可以在 Nextcloud 站台上與其他使用者建立群組，並與他們分享。",
     "Circle" : "小圈圈",
     "User" : "使用者",
@@ -242,6 +248,7 @@ OC.L10N.register(
     "Voice" : "語音",
     "Car" : "車子",
     "Work pager" : "工作呼叫器",
+    "Manager" : "經理",
     "Social network" : "社群網路",
     "Relationship to you" : "與您的關係",
     "Spouse" : "配偶",
@@ -254,7 +261,6 @@ OC.L10N.register(
     "Relative" : "親屬",
     "Friend" : "朋友",
     "Colleague" : "同事",
-    "Manager" : "經理",
     "Assistant" : "助理",
     "Related contacts" : "相關聯絡人",
     "Agent" : "代理人",
